Module ln

Module ln 

Ln and LnAssign, traits for computing the natural logarithm of Floats.

Functions

primitive_float_ln
Computes the natural logarithm of a primitive float. Using this function is more accurate than using the default log function or the one provided by libm.
primitive_float_ln_rational
Computes the natural logarithm of a Rational, returning a primitive float result.