Module ln_1_plus_x

Module ln_1_plus_x 

Ln1PlusX and Ln1PlusXAssign, traits for computing $\ln(1+x)$ for Floats.

Functions

primitive_float_ln_1_plus_x
Computes the natural logarithm of one plus a primitive float, $\ln(1+x)$. Using this function is more accurate than using the primitive float ln_1p function (the standard library’s ln_1p is not correctly rounded).