Module log_base_10

Module log_base_10 

LogBase10 and LogBase10Assign, traits for computing the base-10 logarithm of Floats.

Functions

primitive_float_log_base_10
Computes $\log_{10} x$, the base-10 logarithm of a primitive float. Using this function is more accurate than using the primitive float log10 function (the standard library’s log10 is not always correctly rounded).
primitive_float_log_base_10_rational
Computes $\log_{10} x$, the base-10 logarithm of a Rational, returning a primitive float result.