Module log_base_float_base

Module log_base_float_base 

LogBase and LogBaseAssign, implemented for a Float base, for computing $\log_b x$ of a Float with an arbitrary Float base.

Functions

primitive_float_log_base_float_base
Computes $\log_b x$, the base-$b$ logarithm of a primitive float, where the base $b$ is also a primitive float, returning a primitive float result. Using this function is more accurate than computing the logarithm using the standard library, whose logarithm functions are not always correctly rounded.