LogBaseOf1PlusX and
LogBaseOf1PlusXAssign,
implemented for a Float base, for computing $\log_b(1+x)$ of a
Float with an arbitrary Float base.
Functions
- primitive_
float_ log_ base_ float_ base_ 1_ plus_ x - Computes $\log_b(1+x)$, the base-$b$ logarithm of one plus a primitive float, where the base $b$
is also a primitive float, returning a primitive float result. Using this function is more
accurate than computing the logarithm using the standard library, both because $1+x$ may not be
representable as a primitive float and because the standard library’s
logis not always correctly rounded.