Module log_base_rational_base

Module log_base_rational_base 

LogBase and LogBaseAssign, implemented for a Rational base, for computing $\log_b x$ of a Float with an arbitrary rational base $b>1$.

Functions

primitive_float_log_base_rational_base
Computes $\log_b x$, the base-$b$ logarithm of a primitive float, where $b$ is a Rational greater than 1. Using this function is more accurate than computing the logarithm using the standard library, whose logarithm functions are not always correctly rounded.