Module log_base_rational_float_base

Module log_base_rational_float_base 

Functions for computing $\log_b x$ of a Rational $x$ with an arbitrary Float base, returning a Float.

Functions

primitive_float_log_base_rational_float_base
Computes $\log_b x$, the base-$b$ logarithm of a Rational, where the base $b$ is a primitive float, returning a primitive float result. Using this function is more accurate than computing the logarithm using the standard library, whose logarithm functions are not always correctly rounded.