Module float

Module float 

Float, the crate’s floating-point type, and everything defined on it.

Modules

arithmetic
Traits for arithmetic.
basic
Basic traits for working with Floats.
comparison
Traits for comparing Floats for equality or order.
constants
Functions that produce Float approximations of mathematical constants, using a given precision and rounding mode.
conversion
Traits for converting to and from Floats, including converting Floats to and from strings.
exhaustive
Iterators that generate Floats without repetition.
random
Iterators that generate Floats randomly.

Structs

ComparableFloat
ComparableFloat is a wrapper around a Float, taking the Float by value.
ComparableFloatRef
ComparableFloatRef is a wrapper around a Float, taking the Float be reference.
Float
A floating-point number.