Implementations of AbsSquared and
AbsSquaredAssign, traits for
computing the squared absolute value of a number. For real types this is the same as squaring.
Implementations of AbsSquared and
AbsSquaredAssign, traits for
computing the squared absolute value of a number. For real types this is the same as squaring.