Module acos

Module acos 

Implementations of Acos and AcosAssign, traits for computing the arccosine of Floats.

Functions

primitive_float_acos
Computes $\arccos x$, the arccosine of a primitive float, returning the result as a primitive float.
primitive_float_acos_pi
Computes $\arccos(x)/\pi$, the arccosine of a primitive float measured in half-turns, returning the result as a primitive float.
primitive_float_acos_pi_rational
Computes $\arccos(x)/\pi$, the arccosine of a Rational measured in half-turns, returning the result as a primitive float.
primitive_float_acos_rational
Computes $\arccos x$, the arccosine of a Rational, returning the result as a primitive float.
primitive_float_acos_with_period
Computes $\arccos(x)u/(2\pi)$, the arccosine of a primitive float measured in $u$ths of a turn (so that u = 360 gives degrees), returning the result as a primitive float.
primitive_float_acos_with_period_rational
Computes $\arccos(x)u/(2\pi)$, the arccosine of a Rational measured in $u$ths of a turn (so that u = 360 gives degrees), returning the result as a primitive float.