Module acot

Module acot 

Functions

primitive_float_acot
Computes $\operatorname{acot} x$, the arccotangent of a primitive float, returning the result as a primitive float.
primitive_float_acot_pi
Computes $\operatorname{acot}(x)/\pi$, the arccotangent of a primitive float measured in half-turns, returning the result as a primitive float.
primitive_float_acot_pi_rational
Computes $\operatorname{acot}(x)/\pi$, the arccotangent of a Rational measured in half-turns, returning the result as a primitive float.
primitive_float_acot_rational
Computes $\operatorname{acot} x$, the arccotangent of a Rational, returning the result as a primitive float.
primitive_float_acot_with_period
Computes $\operatorname{acot}(x)u/(2\pi)$, the arccotangent of a primitive float measured in $u$ths of a turn (so that u = 360 gives degrees), returning the result as a primitive float.
primitive_float_acot_with_period_rational
Computes $\operatorname{acot}(x)u/(2\pi)$, the arccotangent of a Rational measured in $u$ths of a turn (so that u = 360 gives degrees), returning the result as a primitive float.