Module acsc

Module acsc 

Functions

primitive_float_acsc
Computes $\operatorname{acsc} x$, the arccosecant of a primitive float, returning the result as a primitive float.
primitive_float_acsc_pi
Computes $\operatorname{acsc}(x)/\pi$, the arccosecant of a primitive float measured in half-turns, returning the result as a primitive float.
primitive_float_acsc_pi_rational
Computes $\operatorname{acsc}(x)/\pi$, the arccosecant of a Rational measured in half-turns, returning the result as a primitive float.
primitive_float_acsc_rational
Computes $\operatorname{acsc} x$, the arccosecant of a Rational, returning the result as a primitive float.
primitive_float_acsc_with_period
Computes $\operatorname{acsc}(x)u/(2\pi)$, the arccosecant of a primitive float measured in $u$ths of a turn (so that u = 360 gives degrees), returning the result as a primitive float.
primitive_float_acsc_with_period_rational
Computes $\operatorname{acsc}(x)u/(2\pi)$, the arccosecant of a Rational measured in $u$ths of a turn (so that u = 360 gives degrees), returning the result as a primitive float.