Module add_mul

Module add_mul 

AddMul and AddMulAssign, traits for adding a Float and the product of two other Floats — or of a Float and a Rational — with a single rounding (fused multiply-add), and the associated precision- and rounding-mode-aware functions.

Functions

primitive_float_add_mul
Adds a primitive float and the product of two other primitive floats with a single rounding, using emulated Float arithmetic.
primitive_float_add_mul_rational
Adds a primitive float and the product of another primitive float and a Rational, with a single rounding, using emulated Float arithmetic.