Module asec

Module asec 

Implementations of Asec and AsecAssign, traits for computing the arcsecant of Floats.

Functions

primitive_float_asec
Computes $\operatorname{asec} x$, the arcsecant of a primitive float, returning the result as a primitive float.
primitive_float_asec_pi
Computes $\operatorname{asec}(x)/\pi$, the arcsecant of a primitive float measured in half-turns, returning the result as a primitive float.
primitive_float_asec_pi_rational
Computes $\operatorname{asec}(x)/\pi$, the arcsecant of a Rational measured in half-turns, returning the result as a primitive float.
primitive_float_asec_rational
Computes $\operatorname{asec} x$, the arcsecant of a Rational, returning the result as a primitive float.
primitive_float_asec_with_period
Computes $\operatorname{asec}(x)u/(2\pi)$, the arcsecant of a primitive float measured in $u$ths of a turn (so that u = 360 gives degrees), returning the result as a primitive float.
primitive_float_asec_with_period_rational
Computes $\operatorname{asec}(x)u/(2\pi)$, the arcsecant of a Rational measured in $u$ths of a turn (so that u = 360 gives degrees), returning the result as a primitive float.