Module asech

Module asech 

Implementations of Asech and AsechAssign, traits for computing the inverse hyperbolic secant of Floats.

Functions

primitive_float_asech
Computes $\operatorname{asech} x$, the inverse hyperbolic secant of a primitive float. Using this function is more accurate than using the default asech function or the one provided by libm.
primitive_float_asech_rational
Computes $\operatorname{asech} x$, the inverse hyperbolic secant of a Rational, returning the result as a primitive float. The result is correctly rounded.