Module asin

Module asin 

Implementations of Asin and AsinAssign, traits for computing the arcsine of Floats.

Functions

primitive_float_asin
Computes $\arcsin x$, the arcsine of a primitive float. Using this function is more accurate than using the default asin function or the one provided by libm.
primitive_float_asin_pi
Computes $\arcsin(x)/\pi$, the arcsine of a primitive float measured in half-turns, returning the result as a primitive float.
primitive_float_asin_pi_rational
Computes $\arcsin(x)/\pi$, the arcsine of a Rational measured in half-turns, returning the result as a primitive float.
primitive_float_asin_rational
Computes $\arcsin x$, the arcsine of a Rational, returning the result as a primitive float.
primitive_float_asin_with_period
Computes $\arcsin(x)u/(2\pi)$, the arcsine of a primitive float measured in $u$ths of a turn (so that u = 360 gives degrees), returning the result as a primitive float.
primitive_float_asin_with_period_rational
Computes $\arcsin(x)u/(2\pi)$, the arcsine of a Rational measured in $u$ths of a turn (so that u = 360 gives degrees), returning the result as a primitive float.