Module asinh

Module asinh 

Implementations of Asinh and AsinhAssign, traits for computing the inverse hyperbolic sine of Floats.

Functions

primitive_float_asinh
Computes $\operatorname{asinh} x$, the inverse hyperbolic sine of a primitive float. Using this function is more accurate than using the default asinh function or the one provided by libm.
primitive_float_asinh_rational
Computes $\operatorname{asinh} x$, the inverse hyperbolic sine of a Rational, returning the result as a primitive float. The result is correctly rounded.