Module atan

Module atan 

Implementations of Atan and AtanAssign, traits for computing the arctangent of Floats.

Functions

primitive_float_atan
Computes $\arctan x$, the arctangent of a primitive float. Using this function is more accurate than using the default atan function or the one provided by libm.
primitive_float_atan_pi
Computes $\arctan(x)/\pi$, the arctangent of a primitive float measured in half-turns.
primitive_float_atan_pi_rational
Computes $\arctan(x)/\pi$, the arctangent of a Rational measured in half-turns, returning the result as a primitive float.
primitive_float_atan_rational
Computes $\arctan x$, the arctangent of a Rational, returning the result as a primitive float.
primitive_float_atan_with_period
Computes $\arctan(x)u/(2\pi)$, the arctangent of a primitive float measured in $u$ths of a turn (so that u = 360 gives degrees).
primitive_float_atan_with_period_rational
Computes $\arctan(x)u/(2\pi)$, the arctangent of a Rational measured in $u$ths of a turn (so that u = 360 gives degrees), returning the result as a primitive float.