primitive_float_cos_rational

Function primitive_float_cos_rational 

pub fn primitive_float_cos_rational<T>(x: &Rational) -> T
where Float: PartialOrd<T>, for<'a> T: ExactFrom<&'a Float> + RoundingFrom<&'a Float> + PrimitiveFloat,
Computes $\cos x$, the cosine of a Rational, returning the result as a primitive float.

$$ f(x) = \cos x+\varepsilon, $$ where $|\varepsilon| < 2^{\lfloor\log_2 |\cos x|\rfloor-p}$, and $p$ is the precision of the output (24 if T is a f32 and 53 if T is a f64).

Special cases:

  • $f(0)=1$

Overflow and underflow are not possible: the result lies in $[-1, 1]$, and a Rational close enough to an odd multiple of $\pi/2$ for its cosine to be subnormal would need a denominator of more than 100 bits, in which case the result is still correctly rounded.

Worst-case complexity

$T(m, e) = O((m+e) (\log (m+e))^2 \log\log (m+e))$

$M(m, e) = O((m+e) \log (m+e))$

where $T$ is time, $M$ is additional memory, $m$ is x.significant_bits(), and $e$ is x.floor_log_base_2_abs() (taken as 0 when it is negative or $x = 0$): for $|x| \geq 4$ the argument is reduced modulo $2\pi$, which needs $\pi$ to about $e$ bits.

Examples

use malachite_base::num::basic::traits::Zero;
use malachite_base::num::float::NiceFloat;
use malachite_float::float::arithmetic::cos::primitive_float_cos_rational;
use malachite_q::Rational;

assert_eq!(
    NiceFloat(primitive_float_cos_rational::<f64>(&Rational::ZERO)),
    NiceFloat(1.0)
);
assert_eq!(
    NiceFloat(primitive_float_cos_rational::<f64>(
        &Rational::from_unsigneds(1u8, 3)
    )),
    NiceFloat(0.9449569463147377)
);
assert_eq!(
    NiceFloat(primitive_float_cos_rational::<f32>(
        &Rational::from_unsigneds(1u8, 3)
    )),
    NiceFloat(0.94495696)
);
assert_eq!(
    NiceFloat(primitive_float_cos_rational::<f64>(&Rational::from(10000))),
    NiceFloat(-0.9521553682590148)
);