Module csc

Module csc 

Implementations of Csc and CscAssign, traits for computing the cosecant of Floats.

Functions

primitive_float_csc
Computes $\csc x$, the cosecant of a primitive float, correctly rounded. Neither the standard library nor libm provides a cosecant.
primitive_float_csc_pi
Computes $\csc(\pi x)$, the cosecant of a primitive float measured in half-turns.
primitive_float_csc_pi_rational
Computes $\csc(\pi x)$, the cosecant of a Rational measured in half-turns, returning the result as a primitive float.
primitive_float_csc_rational
Computes $\csc x$, the cosecant of a Rational, returning the result as a primitive float.
primitive_float_csc_with_period
Computes $\csc(2\pi x/u)$, the cosecant of a primitive float measured in $u$ths of a turn (so that u = 360 is degrees).
primitive_float_csc_with_period_rational
Computes $\csc(2\pi x/u)$, the cosecant of a Rational measured in $u$ths of a turn (so that u = 360 is degrees), returning the result as a primitive float.