Module exp

Module exp 

Exp and ExpAssign, traits for computing $e^x$ for Floats.

Functions

primitive_float_exp
Computes $e^x$, the exponential of a primitive float. Using this function is more accurate than using the default exp function or the one provided by libm.
primitive_float_exp_rational
Computes $e^x$, the exponential of a Rational, returning the result as a primitive float.