Module mul_sub_mul

Module mul_sub_mul 

MulSubMul and MulSubMulAssign, traits for subtracting the product of one pair of Floats from the product of another pair with a single rounding, and the associated precision- and rounding-mode-aware functions.

Functions

primitive_float_mul_sub_mul
Subtracts the product of one pair of primitive floats from the product of another pair with a single rounding, using emulated Float arithmetic.
primitive_float_mul_sub_mul_rational
Subtracts the product of a primitive float and a Rational from the product of two primitive floats, with a single rounding, using emulated Float arithmetic.