Module pow

Module pow 

Implementations of PowerOf2, a trait for computing a power of 2.

Functions

primitive_float_pow
Raises a primitive float to a primitive float power, returning a primitive float.
primitive_float_pow_integer
Raises a primitive float to the power of an Integer, returning a primitive float.
primitive_float_pow_rational
Raises a primitive float to a Rational power, returning a primitive float.
primitive_float_pow_u
Raises a primitive float to the power of a u64, returning a primitive float.
primitive_float_rational_pow
Raises a Rational to a primitive float power, returning a primitive float.
primitive_float_unsigned_pow
Raises a u64 to the power of a primitive float, returning a primitive float.