Module rem

Module rem 

rem_prec_round and related functions, for computing floating-point remainders of Floats.

Functions

primitive_float_ieee_remainder
Computes the IEEE 754 remainder of two primitive floats, with the quotient rounded to the nearest integer (ties to even), using emulated Float arithmetic.
primitive_float_ieee_remainder_and_quotient_bits
Computes the IEEE 754 remainder of two primitive floats along with the low bits of the quotient, with the quotient rounded to the nearest integer (ties to even), using emulated Float arithmetic.
primitive_float_ieee_remainder_rational
Computes the IEEE 754 remainder of a primitive float by a Rational, with the quotient rounded to the nearest integer (ties to even), correctly rounding the result to the nearest value.
primitive_float_ieee_remainder_rational_and_quotient_bits
Computes the IEEE 754 remainder of a primitive float by a Rational along with the low bits of the quotient, with the quotient rounded to the nearest integer (ties to even), correctly rounding the remainder to the nearest value.
primitive_float_rational_ieee_remainder_float
Computes the IEEE 754 remainder of a Rational by a primitive float, with the quotient rounded to the nearest integer (ties to even), correctly rounding the result to the nearest value.
primitive_float_rational_rem_float
Computes the remainder of a Rational by a primitive float, with the quotient rounded toward zero, correctly rounding the result to the nearest value.
primitive_float_rem
Computes the remainder of two primitive floats, with the quotient rounded toward zero, using emulated Float arithmetic.
primitive_float_rem_and_quotient_bits
Computes the remainder of two primitive floats along with the low bits of the quotient, with the quotient rounded toward zero, using emulated Float arithmetic.
primitive_float_rem_rational
Computes the remainder of a primitive float by a Rational, with the quotient rounded toward zero, correctly rounding the result to the nearest value.
primitive_float_rem_rational_and_quotient_bits
Computes the remainder of a primitive float by a Rational along with the low bits of the quotient, with the quotient rounded toward zero, correctly rounding the remainder to the nearest value.
primitive_float_rem_unsigned
Computes the remainder of a primitive float by a u64, with the quotient rounded toward zero, correctly rounding the result to the nearest value.