Module round_to_integer

Module round_to_integer 

Functions

primitive_float_round_to_integer
Rounds a primitive float to an integer using the given rounding mode, using emulated Float arithmetic.
primitive_float_round_to_integer_ties_away
Rounds a primitive float to the nearest integer, with ties away from zero, using emulated Float arithmetic.