Module sub_mul

Module sub_mul 

SubMul and SubMulAssign, traits for subtracting the product of two Floats — or of a Float and a Rational — from another Float with a single rounding (fused multiply-subtract), and the associated precision- and rounding-mode-aware functions.

Functions

primitive_float_sub_mul
Subtracts the product of two primitive floats from another primitive float with a single rounding, using emulated Float arithmetic.
primitive_float_sub_mul_rational
Subtracts the product of a primitive float and a Rational from another primitive float, with a single rounding, using emulated Float arithmetic.