Module tan

Module tan 

Functions

primitive_float_tan
Computes $\tan x$, the tangent of a primitive float. Using this function is more accurate than using the default tan function or the one provided by libm.
primitive_float_tan_pi
Computes $\tan(\pi x)$, the tangent of a primitive float measured in half-turns.
primitive_float_tan_pi_rational
Computes $\tan(\pi x)$, the tangent of a Rational measured in half-turns, returning the result as a primitive float.
primitive_float_tan_rational
Computes $\tan x$, the tangent of a Rational, returning the result as a primitive float.
primitive_float_tan_with_period
Computes $\tan(2\pi x/u)$, the tangent of a primitive float measured in $u$ths of a turn (so that u = 360 is degrees).
primitive_float_tan_with_period_rational
Computes $\tan(2\pi x/u)$, the tangent of a Rational measured in $u$ths of a turn (so that u = 360 is degrees), returning the result as a primitive float.