primitive_float_tanh_rational

Function primitive_float_tanh_rational 

pub fn primitive_float_tanh_rational<T>(x: &Rational) -> T
where Float: PartialOrd<T>, for<'a> T: ExactFrom<&'a Float> + RoundingFrom<&'a Float> + PrimitiveFloat,
Computes $\tanh x$, the hyperbolic tangent of a Rational, returning the result as a primitive float. The result is correctly rounded.

$$ f(x) = \tanh x+\varepsilon. $$

  • If $\tanh x$ is zero, $\varepsilon$ may be ignored or assumed to be 0.
  • If $\tanh x$ is nonzero, then $|\varepsilon| < 2^{\lfloor\log_2 |\tanh x|\rfloor-p}$, where $p$ is the precision of the output (typically 24 if T is a f32 and 53 if T is a f64, but less if the output is subnormal).

Special cases:

  • $f(0)=0.0$

Overflow is not possible, since the result lies in $(-1, 1)$. An x of small enough magnitude underflows to 0.0 or -0.0.

Worst-case complexity

$T(m) = O(m (\log m)^2 \log\log m)$

$M(m) = O(m \log m)$

where $T$ is time, $M$ is additional memory, and $m$ is x.significant_bits().

Examples

use malachite_base::num::basic::traits::Zero;
use malachite_base::num::float::NiceFloat;
use malachite_float::float::arithmetic::tanh::primitive_float_tanh_rational;
use malachite_q::Rational;

assert_eq!(
    NiceFloat(primitive_float_tanh_rational::<f64>(&Rational::ZERO)),
    NiceFloat(0.0)
);
assert_eq!(
    NiceFloat(primitive_float_tanh_rational::<f64>(
        &Rational::from_unsigneds(1u8, 3)
    )),
    NiceFloat(0.32151273753163434)
);
assert_eq!(
    NiceFloat(primitive_float_tanh_rational::<f64>(&Rational::from(
        -10000
    ))),
    NiceFloat(-1.0)
);