Module min_max

Module min_max 

Functions for finding the minimum and maximum of two Floats.

Functions

primitive_float_max_rational
Computes the larger of a primitive float and a Rational, correctly rounding the result to the nearest value.
primitive_float_min_rational
Computes the smaller of a primitive float and a Rational, correctly rounding the result to the nearest value.