Module champernowne_constant

Module champernowne_constant 

Functions for approximating the Champernowne constant in a given base.

Functions

primitive_float_champernowne_constant_base
Computes an approximation of the Champernowne constant in a given base, returning a primitive float.