Module strtofr

Module strtofr 

Functions

set_str
Converts a string to a Float, requiring that the whole string be a valid number.
strtofr
Converts a string to a Float, reading as much of it as forms a valid number.