LogBaseOf1PlusX and
LogBaseOf1PlusXAssign,
traits for computing $\log_b(1+x)$ of Floats for an arbitrary integer base
$b>1$.
Functions
- primitive_
float_ log_ base_ 1_ plus_ x - Computes $\log_b(1+x)$, the base-$b$ logarithm of one plus a primitive float, where $b$ is a
u64greater than 1. Using this function is more accurate than computing the logarithm using the standard library, both because $1+x$ may not be representable as a primitive float and because the standard library’slogis not always correctly rounded.