LogBaseOf1PlusX and
LogBaseOf1PlusXAssign,
implemented for a Rational base, for computing $\log_b(1+x)$ of a
Float with an arbitrary rational base $b>1$.
Functions
- primitive_
float_ log_ base_ rational_ base_ 1_ plus_ x - Computes $\log_b(1+x)$, the base-$b$ logarithm of one plus a primitive float, where the base $b$
is a
Rationalgreater than 1, returning a primitive float result. Using this function is more accurate than computing the logarithm using the standard library, both because $1+x$ may not be representable as a primitive float and because the standard library’slogis not always correctly rounded.