Functions
- primitive_
float_ log_ base_ rational_ float_ base - Computes $\log_b x$, the base-$b$ logarithm of a
Rational, where the base $b$ is a primitive float, returning a primitive float result. Using this function is more accurate than computing the logarithm using the standard library, whose logarithm functions are not always correctly rounded.