pub fn primitive_float_coth_rational<T>(x: &Rational) -> Twhere
Float: PartialOrd<T>,
for<'a> T: ExactFrom<&'a Float> + RoundingFrom<&'a Float> + PrimitiveFloat,Expand description
Computes $\coth x$, the hyperbolic cotangent of a Rational, returning the result as a
primitive float. The result is correctly rounded.
$$ f(x) = \coth x+\varepsilon. $$
- If $\coth x$ is infinite, $\varepsilon$ may be ignored or assumed to be 0.
- If $\coth x$ is finite, then $|\varepsilon| < 2^{\lfloor\log_2 |\coth x|\rfloor-p}$, where $p$
is the precision of the output (24 if
Tis af32and 53 ifTis af64).
Special cases:
- $f(0)=\infty$
An x of magnitude below the reciprocal of the largest finite value gives a result that
overflows to $\pm\infty$. Underflow is not possible, since $|\coth x| > 1$.
Worst-case complexity
$T(m) = O(m (\log m)^2 \log\log m)$
$M(m) = O(m \log m)$
where $T$ is time, $M$ is additional memory, and $m$ is x.significant_bits().
Examples
use malachite_base::num::basic::traits::Zero;
use malachite_base::num::float::NiceFloat;
use malachite_float::float::arithmetic::coth::primitive_float_coth_rational;
use malachite_q::Rational;
assert_eq!(
NiceFloat(primitive_float_coth_rational::<f64>(&Rational::ZERO)),
NiceFloat(f64::INFINITY)
);
assert_eq!(
NiceFloat(primitive_float_coth_rational::<f64>(
&Rational::from_unsigneds(1u8, 3)
)),
NiceFloat(3.110296679619444)
);
assert_eq!(
NiceFloat(primitive_float_coth_rational::<f64>(
&Rational::from_signeds(-1i8, 3)
)),
NiceFloat(-3.110296679619444)
);
assert_eq!(
NiceFloat(primitive_float_coth_rational::<f64>(&Rational::from(10000))),
NiceFloat(1.0)
);